#
# spec file for package polymake
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname   libpolymake4_12
Name:           polymake
Version:        4.12
Release:        1.1
Summary:        Application for studying combinatorics and geometry of convex polytopes
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://polymake.org/

Source:         https://github.com/polymake/polymake/archive/V%version.tar.gz
Source9:        %name-rpmlintrc
Patch2:         sympol-system.patch
Patch3:         perl.patch
BuildRequires:  bliss-devel
BuildRequires:  cddlib-devel
BuildRequires:  fdupes
BuildRequires:  flint-devel
BuildRequires:  gcc-c++ >= 5
BuildRequires:  gmp-devel >= 4.2
BuildRequires:  libSingular-devel
BuildRequires:  libboost_headers-devel
BuildRequires:  libxml2-tools
BuildRequires:  libxslt-tools
BuildRequires:  lrslib-devel >= 7.1b
BuildRequires:  memory-constraints
BuildRequires:  mpfr-devel
BuildRequires:  ninja
BuildRequires:  normaliz-devel
BuildRequires:  perl
BuildRequires:  ppl-devel
BuildRequires:  readline-devel >= 5
BuildRequires:  sympol-devel
BuildRequires:  perl(JSON)
BuildRequires:  pkgconfig(libxml-2.0)
Requires:       perl(JSON)
Requires:       perl(Term::ReadKey)
Requires:       perl(Term::ReadLine::Gnu)
Requires:       perl(XML::SAX)
Suggests:       4ti2
Suggests:       azove
Suggests:       gfan
Suggests:       graphviz
Suggests:       latte
Suggests:       plantri
Suggests:       povray
Suggests:       qhull
Suggests:       web_browser
Suggests:       vinci
Suggests:       mimehandler(application/pdf)
#Suggests:      porta <https://porta.zib.de/>
# web_browser used for displaying SVG

%description
polymake is a tool to study the combinatorics and the geometry of
convex polytopes and polyhedra. It is also capable of dealing with
simplicial complexes, matroids, polyhedral fans, graphs, tropical
objects, and other objects.

%package devel
Summary:        Development files for Polymake plugins
Group:          Development/Libraries/C and C++
Requires:       %name = %version

%description devel
polymake is a tool to study the combinatorics and the geometry of
convex polytopes and polyhedra. It is also capable of dealing with
simplicial complexes, matroids, polyhedral fans, graphs, tropical
objects, and other objects.

%prep
%autosetup -p1

%build
# force using system libnormaliz
rm -rf bundled/libnormaliz/external
# It's not autoconf.
./configure --prefix="%_prefix" --libdir="%_libdir" \
	--libexecdir="%_libdir/%name-%version" --without-native \
	--with-bliss="%_prefix" --with-sympol="%_prefix" --with-cdd="%_prefix" \
	--with-permlib="%_prefix"  --with-lrs="%_prefix" --without-callable \
	CFLAGS="%optflags" CXXFLAGS="%optflags -g0" CXXOPT="%optflags"
# can't replace limit_build by _constraints file:
# * asking memoryperjob=3400 -> unsatisfiable i586 workers
#   (github.com/openSUSE/open-build-service/issues/10167)
# * asking physicalmemory=13600 -> unsatisfiable ppc64 workers
%limit_build -m 3400
make NINJA="ninja %{?_smp_mflags} -v"

%install
%make_install
find "%buildroot/%_includedir" -type f -exec chmod a-x {} +
%fdupes %buildroot/%_prefix

%files
%_bindir/polymake
%_datadir/polymake/
# plugins or something
%_libdir/polymake-%version/
%doc ChangeLog
%license COPYING

%files devel
%_bindir/polymake-config
%_includedir/polymake/

%changelog
* Sun Aug 18 2024 Jan Engelhardt <jengelh@inai.de>
- Add perl.patch, unconstrain perl version
* Fri May 17 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.12
  * fan: fix min_weights for trivial subdivisions
  * graph: rename Lattice to PartiallyOrderedSet
    (keep compat aliases)
  * improve order and chain polytope
  * topaz: many Nevo-Santos-Wilson triangulated spheres
* Thu Nov  9 2023 Jan Engelhardt <jengelh@inai.de>
- polymake uses a number of external programs; add them as
  Suggests.
* Mon Nov  6 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.11
  * Support for Perl 5.38 (but only < 5.40)
  * polydb: new libmongoc interface to polydb (bundled:polydb)
  * polydb: Perl interface removed
  * check_fan: several fixes, including for trivial fans
  * random_matroid: new client
* Tue Jun 13 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.10
  * topcom: extend interface to access other combinations of
    connected, fine, and regular.
* Mon Jan 30 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.9
  * fulton: markov_bases: add new client
  * polytope: mps files: many fixes in parser and writer
* Tue Dec 20 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.8
  * plantri: introduce interface to plantri for generation of
    planar graphs.
  * pluecker_ideal changed to c++ client
  * add tropical median
- Drop vertices-31.patch (merged)
* Sat Nov 19 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.7
  * matroid: Ehrhart polynomial for matroid polytopes
  * polytope: convex_hull: adjust labels to improve prefer behavior
  * polytope: convex_hull: increase weights for count rules
  * polytope: conway: add CG construction
  * topaz: new client poincare_sphere
  * tropical: voronoi_diagram: improve performance
- Add vertices-31.patch
* Fri Jan 14 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.6
  * Polytope changes:
  * new function describe() for Polytope
  * new function secondary_configuration()
  * secondary_polytope() return type changed from
    PointConfiguration to Polytope
  * improve contains function to solve smaller LPs
  * improve conversion methods lp2poly and poly2lp
  * fan: make k_skeleton and common_refinement work properly for
    PolyhedralCom
  * topaz: MINIMAL_NON_FACES type changed to IncidenceMatrix
* Tue Nov  2 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.5
  * Extend flint interface for computations over ZZ/nZZ.
  * Fixed bug giving wrong signs of determinant occasionally
  * New property type DoublyConnectedEdgeList used for Conway
    notation and hyperbolic surfaces.
- Drop bliss077.patch (merged)
* Tue Jun 22 2021 Jan Engelhardt <jengelh@inai.de>
- Add sympol-system.patch to adjust include paths for
  a `make installed` sympol.
- Add bliss077.patch to enable compilation for newer versions
  of bliss.
- Drop unbundle.diff, one can actually use configure arguments.
* Mon Jun 21 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.4
  * libnormaliz: add rules for representation conversion
  * fan: SubdivisionOfPoints: fix bug in MIN_WEIGHTS for
    non-triangulations
  * fan: HyperplaneArrangements: add rule for property
    RAYS_IN_HYPERPLANES
  * fulton: TORIC_IDEAL renamed to CONE_TORIC_IDEAL (and moved to
    application polytope)
* Thu Dec 24 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.3
  * Implement p-adic valuation of rational numbers (via flint)
  * topaz: implement function to compute broken circuit complex
    of a matroid
  * fan: implement function to construct the union of
    cones/polytopes as a subcomplex of a chamber complex
  * Schlegel diagram: fixes for non-rational polytopes
* Sat Sep 26 2020 Jan Engelhardt <jengelh@inai.de>
- Go back from _constraints file to %%limit_build
* Tue Sep  8 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.1
  * Data file format switched from XML to JSON.
  * Basic datatype for all sizes and indexes in C++ is now
    "Int" (typedef) which is "long int".
* Sun Mar 17 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 3.3
  * SCIP: Add interface for solving mixed integer linear programs
  * TOSimplex: Add interface for computing lattice points
  * soplex: Use soplex from SCIP, if available
  * mptopcom: Add interface for computing triangulations of point
    configurations, optionally with group action
  * TOPCOM: If mptopcom.rules is configured, topcom.rules can inherit from this
  * normaliz interface: two minor fixes, added support for
    EHRHART_QUASI_POLYNOMIAL, update normaliz version
  * For more points, see /usr/share/doc/packages/polymake/ChangeLog
- Add unbundle.diff
* Thu Sep 14 2017 jengelh@inai.de
- Update to new upstream release 3.1
  * Support for Perl 5.24
  * Fix incompatibility of the Integer type with libnormaliz on
    32-bit platforms.
  * Completely refactored Polynomial related data types:
  * Rings are now uniquely identified by coefficient type,
    exponent type and number of variables.
  * Variable names are only used for pretty printing and parsing
    (and can be customized).
  * The types Monomial, Term and Ring are gone.
* Sat May 18 2013 jengelh@inai.de
- Initial package (version 2.12~rc3) for build.opensuse.org
